gs_lesson1 Example
==================

Python Version
--------------

Model Code:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/src/gs_lesson1.py
   :language: python
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/gs_lesson1_python.yml
   :language: yaml
   :linenos:



C++ Version
-----------

Model Code:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/src/gs_lesson1.cpp
   :language: c++
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/gs_lesson1_cpp.yml
   :language: yaml
   :linenos:



C Version
---------

Model Code:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/src/gs_lesson1.c
   :language: c
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/gs_lesson1_c.yml
   :language: yaml
   :linenos:



Matlab Version
--------------

Model Code:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/src/gs_lesson1.m
   :language: matlab
   :linenos:


Model YAML:

.. literalinclude:: /../../cis_interface/examples/gs_lesson1/gs_lesson1_matlab.yml
   :language: yaml
   :linenos:



